SystemOrganization addCategory: #'Spec-Bindings'!

Object subclass: #AbstractBindings
	instanceVariableNames: 'classSymbols selectorSymbols'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Spec-Bindings'!

!AbstractBindings commentStamp: '<historical>' prior: 0!
AbstractHolder is an abstract class which handle two dictionaries: one for classes symbol, and one for selectors symbols.!

!AbstractBindings methodsFor: 'protocol' stamp: ''!
classSymbolFor: aSymbol

	^ classSymbols at: aSymbol! !

!AbstractBindings methodsFor: 'protocol' stamp: ''!
classSymbolFor: aSymbol ifAbsent: aBlock

	^ classSymbols at: aSymbol ifAbsent: aBlock! !

!AbstractBindings methodsFor: 'protocol' stamp: ''!
classSymbolFor: aSymbol is: aClassSymbol

	^ classSymbols at: aSymbol put: aClassSymbol! !

!AbstractBindings methodsFor: 'initialization' stamp: 'BenjaminVanRyseghem 3/23/2012 14:55'!
initialize
	"Initialization code for AbstractHolder"

	super initialize.

	classSymbols := self initializeClassesDictionary.
	selectorSymbols := self initializeSelectorsDictionary! !

!AbstractBindings methodsFor: 'initialization' stamp: ''!
initializeClassesDictionary

	^ IdentityDictionary new! !

!AbstractBindings methodsFor: 'initialization' stamp: ''!
initializeSelectorsDictionary

	^ IdentityDictionary new! !

!AbstractBindings methodsFor: 'protocol' stamp: ''!
selectorSymbolFor: aSymbol

	^ selectorSymbols at: aSymbol! !

!AbstractBindings methodsFor: 'protocol' stamp: ''!
selectorSymbolFor: aSymbol ifAbsent: aBlock

	^ selectorSymbols at: aSymbol ifAbsent: aBlock! !

!AbstractBindings methodsFor: 'protocol' stamp: ''!
selectorSymbolFor: aSymbol is: aSelector

	^ selectorSymbols at: aSymbol put: aSelector! !

AbstractBindings subclass: #MorphicBindings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Spec-Bindings'!

!MorphicBindings commentStamp: '<historical>' prior: 0!
MorphicBindings is the class holding the bindings between Spec and Morphic!

!MorphicBindings methodsFor: 'initialization' stamp: 'BenjaminVanRyseghem 4/24/2012 03:17'!
initializeClassesDictionary

	^ IdentityDictionary new
		at: #List 				put: #PluggableListMorph;
		at: #IconList 			put: #PluggableIconListMorph;
		at: #Text 				put: #PluggableTextMorph;
		at: #Button 			put: #PluggableButtonMorph;
		at: #Panel 				put: #PanelMorph;
		at: #Checkbox 			put: #CheckboxMorph;
		at: #DropList 			put: #DropListMorph;
		at: #TextField 			put: #PluggableTextFieldMorph;
		at: #Label 				put: #LabelMorph;
		at: #MultiColumnList 	put: #PluggableMultiColumnListMorph;
		at: #Tree				put: #PluggableTreeMorph;
		at: #FrameLayout		put: #LayoutFrame;
		yourself! !

!MorphicBindings methodsFor: 'initialization' stamp: 'bvr 6/1/2012 17:05'!
initializeSelectorsDictionary

	^ IdentityDictionary new
		at: #addSplitters	 			put: #yourself;
		at: #add:						put: #ensureLayoutAndAddMorph:;
		at: #layout:						put: #layoutFrame:;
		at: #fractions:offsets:			put: #fractions:offsets:;
		at: #useProportionalLayout	put: #changeProportionalLayout;
		at: #vSpaceFill					put: {#vResizing:. #spaceFill};
		at: #hSpaceFill					put: {#hResizing:. #spaceFill};
		at: #vShrinkWrap				put: {#vResizing:. #shrinkWrap};
		at: #hShrinkWrap				put: {#hResizing:. #shrinkWrap};
		at: #vRigid						put: {#vResizing:. #rigid};
		at: #hRigid						put: {#hResizing:. #rigid};
		yourself! !

AbstractBindings subclass: #MorphicBindingsWithSplitters
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Spec-Bindings'!

!MorphicBindingsWithSplitters commentStamp: '<historical>' prior: 0!
MorphicBindingsWithSplitters is like MorphicBindings with splitters support in addition!

!MorphicBindingsWithSplitters methodsFor: 'initialization' stamp: ''!
initializeClassesDictionary

	^ IdentityDictionary new
		at: #Panel put: #PanelMorphWithSplitters;
		yourself! !

!MorphicBindingsWithSplitters methodsFor: 'initialization' stamp: 'BenjaminVanRyseghem 3/23/2012 16:58'!
initializeSelectorsDictionary

	^ IdentityDictionary new
		at: #addSplitters	 put: #addPaneSplitters;
		yourself! !

Object subclass: #BindingsHolder
	instanceVariableNames: 'bindings'
	classVariableNames: 'Bindings'
	poolDictionaries: ''
	category: 'Spec-Bindings'!

!BindingsHolder commentStamp: '<historical>' prior: 0!
A BindingsHolder is a simple wrapper to manage the bindings!

!BindingsHolder class methodsFor: 'accessing' stamp: 'BenjaminVanRyseghem 4/24/2012 10:36'!
bindings

	^ Bindings ifNil: [ Bindings := self defaultBindings ]! !

!BindingsHolder class methodsFor: 'accessing' stamp: 'BenjaminVanRyseghem 4/24/2012 10:37'!
defaultBindings

	^ MorphicBindings new! !

!BindingsHolder methodsFor: 'accessing' stamp: 'BenjaminVanRyseghem 4/24/2012 10:30'!
bindings

	^ bindings! !

!BindingsHolder methodsFor: 'accessing' stamp: 'BenjaminVanRyseghem 4/24/2012 10:30'!
bindings: anObject

	bindings := anObject! !

!BindingsHolder methodsFor: 'protocol' stamp: 'BenjaminVanRyseghem 4/24/2012 10:36'!
classSymbolFor: aSymbol ifAbsent: aBlock

	^ bindings classSymbolFor: aSymbol ifAbsent: aBlock! !

!BindingsHolder methodsFor: 'initialize' stamp: 'BenjaminVanRyseghem 4/24/2012 10:34'!
initialize
	"Initialization code for BindingsHolder"

	super initialize.

	bindings := MorphicBindings new.! !

!BindingsHolder methodsFor: 'protocol' stamp: 'BenjaminVanRyseghem 4/24/2012 10:29'!
retrieveClassSymbolFor: aSymbol

	^ self bindings
		ifNil: [ self retrieveDefaultClassSymbolFor: aSymbol ]
		ifNotNil: [:bdg | bdg classSymbolFor: aSymbol ifAbsent: [ self retrieveDefaultClassSymbolFor: aSymbol ]]! !

!BindingsHolder methodsFor: 'protocol' stamp: 'BenjaminVanRyseghem 4/24/2012 10:29'!
retrieveDefaultClassSymbolFor: aSymbol

	^ self class bindings classSymbolFor: aSymbol ifAbsent: [ aSymbol ]! !

!BindingsHolder methodsFor: 'protocol' stamp: 'BenjaminVanRyseghem 4/24/2012 10:29'!
retrieveDefaultSelectorSymbolFor: aSymbol

	^ self class bindings selectorSymbolFor: aSymbol ifAbsent: [ aSymbol ]! !

!BindingsHolder methodsFor: 'protocol' stamp: 'BenjaminVanRyseghem 4/24/2012 10:29'!
retrieveSelectorSymbolFor: aSymbol

	^ self bindings
		ifNil: [ self retrieveDefaultSelectorSymbolFor: aSymbol ]
		ifNotNil: [:binding | binding selectorSymbolFor: aSymbol ifAbsent: [ self retrieveDefaultSelectorSymbolFor: aSymbol ]]! !

!BindingsHolder methodsFor: 'protocol' stamp: 'BenjaminVanRyseghem 4/24/2012 10:35'!
selectorSymbolFor: aSymbol ifAbsent: aBlock

	^ bindings selectorSymbolFor: aSymbol ifAbsent: aBlock! !
